@@ -10,7 +10,7 @@ region = settings.AWS_REGION
 dynamodb_state_table_name = settings.DYNAMODB_STATE_TABLE_NAME+'-'+settings.ENVIRONMENT
 bucket_name = settings.S3_BUCKET_NAME
 
-if settings.ENVIRONMENT == 'local':  # not gonna need this on local
+if settings.ENVIRONMENT != 'local':  # not gonna need this on local
     dynamodb = boto3.resource('dynamodb', region_name=region)
     s3 = boto3.resource('s3', region_name=region)
 
